(function (Drupal, drupalSettings) {

  /**
   * EBT Countdown behavior.
   */
  Drupal.behaviors.ebtCountDown = {
    attach: function (context, settings) {
      // Initialize once behavior.
      var countdowns = once('ebt-countdown-block', '.ebt-countdown-date', context);

      countdowns.forEach(function(countdown) {
        // Get block ID.
        var countdownWrapper = countdown.closest('.ebt-block-countdown');
        if (!countdownWrapper) {
          console.warn('EBT Countdown: Countdown wrapper not found.');
          return;
        }

        var countdownWrapperId = countdownWrapper.getAttribute('id');

        // Get block EBT settings.
        if (!drupalSettings['ebtCountdown'] || !drupalSettings['ebtCountdown'][countdownWrapperId]) {
          console.warn('EBT Countdown: Settings not found for ID: ' + countdownWrapperId);
          return;
        }

        var ebtOptions = drupalSettings['ebtCountdown'][countdownWrapperId];

        // Prepare options for javascript plugin.
        var countdownTimestamp = parseInt(countdown.getAttribute('data-date'), 10);
        if (isNaN(countdownTimestamp)) {
          console.warn('EBT Countdown: Invalid timestamp for countdown.');
          return;
        }

        var countdownId = countdown.getAttribute('id');

        // Init javascript plugin.
        if (typeof FlipDown === 'function') {
          try {
            new FlipDown(countdownTimestamp, countdownId, {
              theme: ebtOptions['options']['color_theme'],
              headings: [
                ebtOptions['options']['heading_days'],
                ebtOptions['options']['heading_hours'],
                ebtOptions['options']['heading_minutes'],
                ebtOptions['options']['heading_seconds'],
              ],
            }).start();
          } catch (error) {
            console.error('EBT Countdown: Failed to initialize FlipDown.', error);
          }
        } else {
          console.warn('EBT Countdown: FlipDown library is missing or not loaded.');
        }
      });
    }
  };

})(Drupal, drupalSettings);
